OC.L10N.register(
    "core",
    {
    "Please select a file." : "من فضلك حدد الملف",
    "File is too big" : "حجم الملف أكبر من المسموح",
    "The selected file is not an image." : "الملف المحدد ليس صورة ",
    "The selected file cannot be read." : "الملف المحدد لا يمكن قرأته",
    "The file was uploaded" : "تم رفع الملف",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم الملف المرفوع قد تجاوز  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد رفعه أعلى من الحد المسموح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "تم رفع الملف بشكل جزئي فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "تعذر نسخ الملف الى القرص",
    "A PHP extension stopped the file upload" : "أوقف امتداد PHP تحميل الملف",
    "Invalid file provided" : "تم تقديم ملف غير صالح",
    "No image or file provided" : "لم يتم توفير صورة أو ملف",
    "Unknown filetype" : "نوع الملف غير معروف",
    "An error occurred. Please contact your admin." : "حدث خطأ، يرجى مراجعة المسؤول.",
    "Invalid image" : "الصورة غير صالحة",
    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
    "No crop data provided" : "لم يتم تحديد قص البيانات.",
    "No valid crop data provided" : "تحديد قص البيانات غير صحيح.",
    "Crop is not square" : "القص ليس مربعا",
    "State token does not match" : "حالة Token غير مطابقة",
    "Invalid app password" : "كلمة المرور للتطبيق غير صحيحه",
    "Could not complete login" : "لا يمكن إكمال عملية تسجيل الدخول",
    "Your login token is invalid or has expired" : "معلومات الجلسة غير صالحة أو منتهية",
    "Login" : "الدخول",
    "Please try again" : "يرجى إعادة المحاولة",
    "Password reset is disabled" : "تم تعطيل إعادة تعيين كلمة المرور",
    "Could not reset password because the token is expired" : "لا يمكن إعادة تعيين كلمة المرور بسبب انتهاء صلاحية الجلسة.",
    "Could not reset password because the token is invalid" : "لا يمكن إعادة تعيين كلمة المرور بسبب خطأ في تكوين الجلسة",
    "%s password reset" : "%s إعادة تعيين كلمة مرور ",
    "Password reset" : "إعادة تعيين كلمة مرور",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "اضغط على الزر بالاسفل لإعادة تعيين كلمة المرور. إذا لم تطلب إعادة تعيين كلمة المرور، يرجى تجاهل هذه الرسالة.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "اضغط على الزر بالاسفل لإعادة تعيين كلمة المرور. إذا لم تطلب إعادة تعيين كلمة المرور، يرجى تجاهل هذه الرسالة.",
    "Reset your password" : "أعد تعيين كلمة المرور",
    "Nextcloud Server" : "خادم نكست كلاود",
    "Some of your link shares have been removed" : "تم ازالة البعض من مشاركة الروابط الخاصة بك.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "نظرا لسبب آمني تم ازالة البعض من روابط المشاركة الخاصة بك. يرجى مراجعة الرابط التالي لمزيد من التفاصيل.",
    "The user limit of this instance is reached." : "وصل المستخدم إلى الحد من هذه النسخة",
    "Learn more ↗" : "تعلم المزيد ↗",
    "Preparing update" : "جارٍ تهيئة التحديث",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair step:" : "خطوة صيانة:",
    "Repair info:" : "معلومات صيانة:",
    "Repair warning:" : "تحذير صيانة:",
    "Repair error:" : "خطأ صيانة:",
    "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
    "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
    "Maintenance mode is kept active" : "لم يزل وضع الصيانة نشط",
    "Updating database schema" : "يحدث مخطط قاعدة البيانات",
    "Updated database" : "قاعدة بيانات محدثة",
    "Update app \"%s\" from App Store" : "قم بتحديث التطبيق \"%s\" عن طريق متجر التطبيقات",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "جاري فحص إذا كان مخطط قاعدة البيانات لـ %s يمكن تحديثه (قد يستغرق ذلك بعض الوقت اعتمادًا على مساحة قاعدة البيانات)",
    "Updated \"%1$s\" to %2$s" : "حدث \"%1$s\" إلى %2$s",
    "Set log level to debug" : "أعد تعيين مستوى السجلات إلى اكتشاف الاخطاء المفصلة",
    "Reset log level" : "أعد تعيين مستوى السجلات",
    "Starting code integrity check" : "البدء في فحص دمج الاكواد",
    "Finished code integrity check" : "انتهى فحص دمج الاكواد",
    "%s (incompatible)" : "%s (غير متوافق)",
    "The following apps have been disabled: %s" : "التطبيقات التاليه غير مفعله: %s",
    "Already up to date" : "محدّثة مسبقاً",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : " لم يتم تعيين السماح لخادمك السحابي بتزامن الملف، بسبب واجهة التأليف الموزع على الويب وتعيين الإصدار WebDAV غير متصلة.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : " لم يتم ضبط خادمك السحابي لتعيين الكشف عن \"{url}\". للمزيد من التفاصيل يمكن العثور عليها في  {linkstart}مستند  ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : " لم يتم ضبط تعيين الكشف عن \"{url}\"في خادمك السحابي. من الغالب يجب تغيير اعدادات الخادم السحابي لعدم توصيل المجلد بشكل مباشر. الرجاء مقارنة إعداداتك مع الإعدادات الإصلية لملف \".htaccess\" لاباتشي أو نجينكس في {linkstart} صفحة التوثيق ↗ {linkend}. في Nginx ، عادةً ما تكون هذه الأسطر التي تبدأ بـ \"location ~\" والتي تحتاج إلى تحديث.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "خادمك السحابي لم يتم ضبطه لـ تعيين توصيل نوع .woff2 من الملفات. بالغالب هذه المشكلة تخص اعدادات نجينكس. لـ نيكست كلاود الاصدار 15 يتم اعادة تنظيم وضبط إعدادات التوصيل لملفات .woff2 .قارن تهيئة Nginx بالتهيئة الموصى بها في وثائق {linkstart} الخاصة بنا ↗ {linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "يبدو أن PHP لم يتم إعدادها بشكل صحيح للاستعلام عن متغيرات بيئة النظام. يقوم الاختبار باستخدام getenv (\"PATH\") بإرجاع استجابة فارغة فقط.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "يرجى التحقق من {linkstart} مستند التثبيت ↗{linkend} لملاحظات إعدادات PHP وإعدادات PHP لخادمك السحابي ، خاصة عند استخدام php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "تم تمكين إعداد للقراءة فقط. هذا يمنع تعيين بعض الإعدادات عبر واجهة الويب. علاوة على ذلك ، يجب جعل الملف قابلاً للكتابة يدويًا لكل تحديث.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "لم تقم بالتعيين أو التحقق من تكوين خادم البريد الإلكتروني الخاص بك ، حتى الآن. يرجى التوجه إلى {mailSettingsStart} الإعدادات الأساسية {mailSettingsEnd} لتعيينها. بعد ذلك ، استخدم الزر \"إرسال بريد إلكتروني\" أسفل النموذج للتحقق من إعداداتك.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "لا تعمل قاعدة البيانات الخاصة بك بمستوى عزل المعاملة \"READ COMMITTED\". هذا يمكن أن يسبب مشاكل عند تنفيذ عدة إجراءات بالتوازي.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "وحدة PHP \"fileinfo\" مفقودة. يوصى بشدة بتمكين هذه الوحدة للحصول على أفضل النتائج مع اكتشاف نوع MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "قفل ملف المعاملات معطل ، قد يؤدي ذلك إلى مشاكل تتعلق بظروف السباق. قم بتمكين \"filelocking.enabled\" في config.php لتجنب هذه المشاكل. راجع وثائق {linkstart} ↗ {linkend} لمزيد من المعلومات.",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "لم يتم تعيين منطقة هاتف افتراضية في التثبيت الخاص بك، وهو مطلوب للتحقق من صحة أرقام الهواتف في إعدادات الملف الشخصي بدون رمز البلد. للسماح بالأرقام بدون رمز البلد ، يُرجى إضافة \"default_phone_region\" باستخدام {linkstart} رمز ISO 3166-1 المعني ↗ {linkend} الخاص بالمنطقة إلى ملف التكوين الخاص بك.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "غير ممكن تنفيذ مهمة cron عبر CLI. ظهرت الأخطاء الفنية التالية:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "تم تنفيذ آخر مهمة في الخلفية {relativeTime}. يبدو أن هناك خطأ ما. {linkstart} تحقق من إعدادات الخلفية ↗ {linkend}.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "لم يتم تكوين ذاكرة تخزين مؤقت، لتحسين الأداء ، يرجى تكوين memcache ، إذا كان ذلك متاحًا. يمكن العثور على مزيد من المعلومات في هذا {linkstart}المستند {linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "لم يتم العثور على مصدر مناسب randomness بواسطة PHP وهو مهم لأسباب أمنية. يمكن العثور على مزيد من المعلومات في هذه  {linkstart}المستند {linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "تقوم حاليا بتشغيل PHP {version}. قم بترقية إصدار PHP الخاص بك للاستفادة من تحديثات الأداء والأمان الخاصة بـ {linkstart} التي توفرها PHP Group ↗ {linkend} بمجرد أن تدعمها التوزيعات الخاصة بك.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "إعدادات reverse proxy header غير صحيحه ، أو أنك تقوم بالوصول إلى نكست كلاود من وكيل موثوق به. إذا لم يكن الأمر كذلك ، فهذه مشكلة أمنية ويمكن أن تسمح للمخترقين بانتحال عنوان IP الخاص بهم كما هو مرئي لنكست كلاود. يمكن العثور على المزيد من المعلومات في هذا {linkstart}المستند {linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "تم تكوين Memcached كذاكرة تخزين مؤقت موزعة ، ولكن تم تثبيت وحدة PHP الخاطئة \"memcache\". \\ OC \\ Memcache \\ Memcached يدعم فقط \"memcached\" وليس \"memcache\". انظر {linkstart} الويكي memcached حول كلا الوحدتين {linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "لم تجتز بعض الملفات اختبار السلامة. يمكن العثور على مزيد من المعلومات حول كيفية حل هذه المشكلة في {linkstart1}  التعليمات↗{linkend}. ({linkstart2} قائمة الملفات غير الصالحة …{linkend} / {linkstart3} إعادة الفحص ...{linkend})",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "وظيفة PHP \"set_time_limit\" غير متاحة. قد يؤدي هذا إلى توقف البرامج النصية في منتصف التنفيذ ، مما يؤدي إلى تعطيل التثبيت. يوصى بشدة بتمكين هذه الوظيفة.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "لا يحتوي PHP على دعم FreeType ، مما يؤدي إلى كسر صور الملف الشخصي وواجهة الإعدادات.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "الفهرس \"{indexName}\" مفقود في الجدول \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "تفتقد قاعدة البيانات إلى بعض الفهارس. نظرًا لحقيقة أن إضافة الفهارس على الجداول الكبيرة قد تستغرق بعض الوقت لم تتم إضافتها تلقائيًا. من خلال تشغيل \"occ db: add-missing-indexices\" ، يمكن إضافة تلك الفهارس المفقودة يدويًا أثناء استمرار تشغيل الخادم. بمجرد إضافة الفهارس، تكون الاستعلامات إلى هذه الجداول عادةً أسرع بكثير.",
    "Missing primary key on table \"{tableName}\"." : "المفتاح الأساسي مفقود في الجدول \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "تفتقد قاعدة البيانات إلى بعض المفاتيح الأساسية. نظرًا لحقيقة أن إضافة المفاتيح الأساسية على الطاولات الكبيرة قد تستغرق بعض الوقت لم تتم إضافتها تلقائيًا. من خلال تشغيل \"occ db: add-missing-basic-keys\" يمكن إضافة تلك المفاتيح الأساسية المفقودة يدويًا أثناء استمرار تشغيل الخادم.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "العمود الاختياري \"{columnName}\" مفقود في الجدول \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "تفتقد قاعدة البيانات إلى بعض الأعمدة الاختيارية. نظرًا لحقيقة أن إضافة أعمدة على الجداول الكبيرة قد تستغرق بعض الوقت لم تتم إضافتها تلقائيًا عندما يمكن أن تكون اختيارية. من خلال تشغيل \"occ db: add-missing-columns\" ، يمكن إضافة الأعمدة المفقودة يدويًا أثناء استمرار تشغيل الخادم. بمجرد إضافة الأعمدة ، قد تعمل بعض الميزات على تحسين الاستجابة أو قابلية الاستخدام.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "يفتقد هذا المثال إلى بعض وحدات PHP الموصى بها. للحصول على أداء أفضل وتوافق أفضل ، يوصى بشدة بتثبيتها.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "الحزمة php-imagick في هذا الخادم لا تدعم SVG. لتوافق افضل من المستحسن دعمها.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "يتم استخدام SQLite حاليًا كقاعدة بيانات خلفية. بالنسبة لعمليات التثبيت الأكبر ، نوصي بالتبديل إلى خلفية قاعدة بيانات مختلفة.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "يوصى بهذا بشكل خاص عند استخدام تطبيق سطح المكتب لمزامنة الملفات.",
    "The PHP memory limit is below the recommended value of 512MB." : "حد ذاكرة PHP أقل من القيمة الموصى بها وهي 512 ميجا بايت.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "بعض مجلدات التطبيق مملوكة لمستخدم مختلف عن مستخدم خادم الويب. قد يكون هذا هو الحال إذا تم تثبيت التطبيقات يدويًا. تحقق من صلاحيات مجلدات التطبيق التالية:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "تُستخدم MySQL كقاعدة بيانات ولكنها لا تدعم الأحرف المكونة من 4 بايت. لتكون قادرًا على التعامل مع أحرف 4 بايت (مثل emojis) دون مشاكل في أسماء الملفات أو التعليقات ، على سبيل المثال ، يوصى بتمكين دعم 4 بايت في MySQL. لمزيد من التفاصيل اقرأ {linkstart} صفحة التعليمات حول هذا الموضوع ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "يستخدم هذا الخادم مخزن عناصر يستند إلى S3 كتخزين أساسي. يتم تخزين الملفات التي تم تحميلها مؤقتًا على الخادم ، وبالتالي يوصى بتوفير مساحة خالية تبلغ 50 جيجابايت في المجلد المؤقت لـ PHP. تحقق من السجلات للحصول على تفاصيل كاملة حول المسار والمساحة المتاحة. لتحسين هذا الرجاء تغيير المجلد المؤقت في ملف php.ini أو توفير مساحة أكبر في هذا المسار.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "أنت تقوم بالوصول إلى خادمك السحابي عبر اتصال آمن ، ولكن يقوم المثيل الخاص بك بإنشاء عناوين URL غير آمنة. هذا يعني على الأرجح أنك تعمل خلف reverse proxy وأن متغيرات تكوين الكتابة لم تعيين بشكل صحيح. يرجى قراءة {linkstart} صفحة التعليمات حول هذا الموضوع ↗{linkend}.",
    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "لم يتم تعيين رأس HTTP \"{header}\" على \"{expected}\". يعد هذا خطرًا محتملاً على الأمان أو الخصوصية ، حيث يوصى بضبط هذا الإعداد وفقًا لذلك.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "لم يتم تعيين رأس HTTP \"{header}\" على \"{expected}\". قد لا تعمل بعض الميزات بشكل صحيح ، حيث يوصى بضبط هذا الإعداد وفقًا لذلك.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "لم يتم تعيين رأس HTTP \"{header}\" على \"{val1}\" أو \"{val2}\" أو \"{val3}\" أو \"{val4}\" أو \"{val5}\". يمكن أن يؤدي هذا إلى تسريب معلومات المرجع. راجع {linkstart} توصية W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "لم يتم تعيين رأس HTTP \"Strict-Transport-Security\" على \"{seconds}\" ثانية على الأقل. لتحسين الأمان ، يوصى بتمكين HSTS كما هو موضح في {linkstart} إرشادات الأمان ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "الوصول إلى الموقع بشكل غير آمن عبر HTTP. يُنصح بشدة تعيين الخادم الخاص بك لطلب HTTPS بدلاً من ذلك ، كما هو موضح في  {linkstart} إرشادات الأمان ↗{linkend}.",
    "unknown text" : "النص غير معروف",
    "Hello world!" : "مرحبا بالعالم!",
    "sunny" : "مشمس",
    "Hello {name}, the weather is {weather}" : "مرحبًا {name}، حالة الطقس {weather}",
    "Hello {name}" : "مرحبا {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>هذه هي نتائج البحث الخاصة بك <script>تنبيه(1)</script> </strong>",
    "new" : "جديد",
    "_download %n file_::_download %n files_" : ["تنزيل %n ملف","تنزيل ملف واحد","تنزيل ملفين","تنزيل %n ملفات","تنزيل %n ملفات","تنزيل %n ملفات"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "جاري التحديث، وقد يؤدي مغادرة هذه الصفحة إلى توقف العملية في بعض الاحيان.",
    "Update to {version}" : "التحديث إلى {version}",
    "An error occurred." : "حدث خطأ.",
    "Please reload the page." : "رجاء أعد تحميل الصفحة.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "فشل التحديث. لمزيد من المعلومات <a href=\"{url}\"> تصفح مقالات المنتدى الخاص بنا </a> لإصلاح هذا الخطأ.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "فشل التحديث. يرجى التبليغ عن هذه المشكلة إلى <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> مجتمع Nextcloud </a>.",
    "Continue to {productName}" : "أكمل إلى {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال%n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني."],
    "More apps" : "المزيد من التطبيقات",
    "Log in" : "تسجيل الدخول",
    "Logging in …" : "تسجيل الدخول …",
    "Server side authentication failed!" : "رفض الخادم المصادقة!",
    "Please contact your administrator." : "يرجى التواصل مع مسؤول النظام.",
    "An internal error occurred." : "حدث خطأ داخلي.",
    "Please try again or contact your administrator." : "حاول مجددا أو تواصل مع مسؤول النظام.",
    "Account name or email" : "اسم الحساب أو البريد الالكتروني",
    "Password" : "كلمة المرور",
    "Log in to {productName}" : "الولوج إلى {productName}",
    "Wrong username or password." : "اسم المستخدم أو كلمة المرور خاطئة.",
    "User disabled" : "المستخدم معطّل",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "لقد اكتشفنا عدة محاولات تسجيل دخول غير صالحة من عنوان IP الخاص بك. لذلك تم تقييد تسجيل الدخول التالي الخاص بك حتى 30 ثانية.",
    "Username or email" : "اسم المستخدم أو البريد الالكتروني",
    "Your account is not setup for passwordless login." : "لم يتم إعداد حسابك لتسجيل الدخول بدون كلمة مرور.",
    "Browser not supported" : "المتصفح غير مدعوم",
    "Passwordless authentication is not supported in your browser." : "المصادقة بدون كلمة مرور غير مدعومة في متصفحك.",
    "Your connection is not secure" : "اتصالك غير آمن",
    "Passwordless authentication is only available over a secure connection." : "المصادقة بدون كلمة مرور متاحة فقط عبر اتصال آمن.",
    "Reset password" : "تعديل كلمة السر",
    "Couldn't send reset email. Please contact your administrator." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. يرجى مراجعة المسؤول.",
    "Password cannot be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تحدث مع المسؤول.",
    "Back to login" : "العودة إلى تسجيل الدخول",
    "New password" : "كلمات سر جديدة",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "المحتوى الخاص بك مشفر. لن تكون هناك طريقة لاستعادة محتوياتك وبياناتك بعد إعادة تعيين كلمة مرورك. إذا لم تكن متأكدًا مما يجب فعله ، فيرجى الاتصال بالمسؤول قبل المتابعة. هل حقا تريد الاستمرار؟",
    "I know what I'm doing" : "أعرف ماذا أفعل",
    "Resetting password" : "إعادة تعيين كلمة المرور",
    "Recommended apps" : "التطبيقات المستحسنة",
    "Loading apps …" : "تحميل التطبيقات…",
    "Could not fetch list of apps from the App Store." : "لا يمكن العثور على قائمة التطبيقات من متجر التطبيقات.",
    "Installing apps …" : "جاري تثبيت التطبيقات…",
    "App download or installation failed" : "فشل تحميل أو تثبيت التطبيق ",
    "Cannot install this app because it is not compatible" : "لا يمكن تثبيت هذا التطبيق لانه غير متوافق",
    "Cannot install this app" : "لا يمكن تثبيت هذا التطبيق",
    "Skip" : "تخطي",
    "Install recommended apps" : "ثبت التطبيقات الاضافيه",
    "Schedule work & meetings, synced with all your devices." : "قم بجدولة العمل والإجتماعات ، بالتزامن مع جميع أجهزتك.",
    "Keep your colleagues and friends in one place without leaking their private info." : "احتفظ بزملائك وأصدقائك في مكان واحد دون تسريب معلوماتهم الخاصة.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "تطبيق بريد إلكتروني بسيط متوافق بشكل ممتاز مع الملفات وجهات الاتصال والتقويم.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "الدردشة ومكالمات الفيديو ومشاركة الشاشة والإجتماعات عبر الإنترنت ومؤتمرات الويب - في متصفحك ومع تطبيق للهاتف المحمول.",
    "Forgot password?" : "هل نسيت كلمة السر ؟",
    "Log in with a device" : "سجل دخولك عن طريق جهاز",
    "Back" : "العودة",
    "Login form is disabled." : "نموذج تسجيل الدخول معطل",
    "Edit Profile" : "تعديل الملف الشخصي",
    "You have not added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن",
    "Error opening the user status modal, try hard refreshing the page" : "خطأ في فتح حالة المستخدم ، حاول تحديث الصفحة",
    "Reset search" : "إعادة تعيين البحث",
    "Start search" : "ابدأ البحث",
    "Search for {name} only" : "البحث عن {name} فقط",
    "Start typing to search" : "اكتب هنا للبحث",
    "Loading more results …" : "جاري عرض المزيد من النتائج…",
    "Load more results" : " عرض المزيد من النتائج",
    "Search" : "البحث",
    "No results for {query}" : "لا يوجد ناتج لـ {query}",
    "An error occurred while searching for {type}" : "حدث خطأ أثناء البحث عن {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength}  أو أكثر للبحث"],
    "Settings menu" : "قائمة الإعدادات",
    "Search {types} …" : "بحث {types} …",
    "Settings" : "الإعدادات",
    "Could not load your contacts" : "تعذر تحميل جهات الإتصال",
    "Search contacts …" : "البحث عن جهات الإتصال",
    "No contacts found" : "لم يعثر على جهات اتصال",
    "Show all contacts …" : "إظهار كافة جهات الإتصال …",
    "Install the Contacts app" : "تثبيت تطبيق جهات الإتصال",
    "Loading your contacts …" : "تحميل جهات الإتصال",
    "Looking for {term} …" : "جاري البحث عن {term}",
    "No" : "لا",
    "Yes" : "نعم",
    "No files in here" : "لا توجد ملفات هنا",
    "New folder" : "مجلد جديد",
    "No more subfolders in here" : "لا يوجد هنا ملفات فرعية",
    "Name" : "الاسم",
    "Size" : "الحجم",
    "Modified" : "آخر تعديل",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "\"/\" is not allowed inside a file name." : "\"/\" غير مسموح في تسمية الملف",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" أنه نوع ملف غير مسموح",
    "{newName} already exists" : "{newname} موجود مسبقاً",
    "Choose" : "اختيار",
    "Copy" : "نسخ",
    "Move" : "نقل",
    "Error loading file picker template: {error}" : "حصل خطأ في اختيار القالب: {error}",
    "OK" : "موافق",
    "Error loading message template: {error}" : "حصل خطأ في القالب: {error}",
    "read-only" : "قراءة فقط",
    "_{count} file conflict_::_{count} file conflicts_" : ["لا يوجد تعارض","{count} ملف متعارض","ملفان متعارضان","{count} ملفات متعارضة"," {count} ملفا متعارضا","{count} ملفات متعارضه"],
    "One file conflict" : "تعارض ملف واحد",
    "New Files" : "ملفات جديدة",
    "Already existing files" : "المفات موجودة مسبقاً",
    "Which files do you want to keep?" : "ماهي الملفات التي ترغب في إبقاءها ؟",
    "If you select both versions, the copied file will have a number added to its name." : "عند إختيار كلا النسختين. المف المنسوخ سيحتوي على رقم في إسمه.",
    "Cancel" : "إلغاء",
    "Continue" : "المتابعة",
    "(all selected)" : "(إختيار الكل)",
    "({count} selected)" : "({count} تم تحديد)",
    "Error loading file exists template" : "خطأ في تحميل القالب الحالي",
    "Show list view" : "اظهر معاينات الروابط",
    "Pending" : "معلّق",
    "Home" : "الرئيسية",
    "Copy to {folder}" : "أنسخ إلى {folder}",
    "Move to {folder}" : "النقل إلى {folder}",
    "Saving …" : "جاري الحفظ…",
    "Authentication required" : "المصادقة مطلوبة",
    "This action requires you to confirm your password" : "يتطلب هذا الإجراء منك تأكيد كلمة المرور",
    "Confirm" : "تأكيد",
    "Failed to authenticate, try again" : "أخفقت المصادقة، أعد المحاولة",
    "seconds ago" : "منذ ثواني",
    "Connection to server lost" : "تم فقد الاتصال بالخادم",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثانية","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني."],
    "Add to a project" : "إضافة إلى مشروع",
    "Show details" : "عرض التفاصيل",
    "Hide details" : "إخفاء التفاصيل",
    "Rename project" : "إعادة تسمية المشروع",
    "Failed to rename the project" : "فشل في إعادة تسمية المشروع",
    "Failed to create a project" : "فشل في إنشاء مشروع",
    "Failed to add the item to the project" : "فشل في إضافة المحتوى إلى المشروع",
    "Connect items to a project to make them easier to find" : "اربط المحتوى إلى المشروع للوصول إليه بسهوله",
    "Type to search for existing projects" : "اكتب هنا للبحث عن مشاريع مسجلة",
    "New in" : "الجديد في",
    "View changelog" : "اعرض سجل التغييرات",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "So-so password" : "كلمة سر غير فعالة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "No action available" : "لا يتوفر أي إجراء",
    "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
    "Non-existing tag #{tag}" : "وسم غير موجود #{tag}",
    "Restricted" : "مقيدة",
    "Invisible" : "مخفي",
    "Delete" : "إلغاء",
    "Rename" : "إعادة التسمية",
    "Collaborative tags" : "أوسمة تعاونية",
    "No tags found" : "لم يُعثَر على أي وسم",
    "Personal" : "شخصي",
    "Users" : "المستخدمين",
    "Apps" : "التطبيقات",
    "Admin" : "المدير",
    "Help" : "المساعدة",
    "Access forbidden" : "الوصول محظور",
    "The profile does not exist." : "الملف الشخصي غير موجود.",
    "Back to %s" : "العودة إلى %s",
    "Too many requests" : "الطلبات أقصى من الحد المسموح",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "يوجد طلبات أقصى من الحد المسموح به في الشبكة. أعد المحاولة أو اتصل بمسؤول النظام.",
    "Error" : "خطأ",
    "Previous" : "السابق",
    "Internal Server Error" : "خطأ داخلي في الخادم",
    "The server was unable to complete your request." : "لا يمكن معالجة طلبك",
    "If this happens again, please send the technical details below to the server administrator." : "إذا حدث هذا مرة أخرى ، يرجى إرسال التفاصيل الفنية أدناه إلى مسؤول الخادم.",
    "More details can be found in the server log." : "مزيد من التفاصيل في سجلات الخادم.",
    "Technical details" : "تفاصيل تقنية",
    "Remote Address: %s" : "العنوان البعدي : %s",
    "Request ID: %s" : "رقم الطلب: %s",
    "Type: %s" : "النوع : %s",
    "Code: %s" : "الرمز : %s",
    "Message: %s" : "الرسالة : %s",
    "File: %s" : "ملف : %s",
    "Line: %s" : "السطر: %s",
    "Trace" : "متابعة",
    "Security warning" : "تحذير الأمان",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "للحصول على معلومات حول كيفية تكوين الخادم الخاص بك، يرجى الاطلاع على <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">التعليمات</a>.",
    "Create an <strong>admin account</strong>" : "أضف <strong>مستخدم رئيسي</strong> ",
    "Username" : "إسم المستخدم",
    "Show password" : "اظهر كلمة المرور",
    "Storage & database" : "التخزين و قاعدة البيانات",
    "Data folder" : "مجلد المعلومات",
    "Configure the database" : "إعداد قاعدة البيانات",
    "Only %s is available." : "لم يتبقى إلّا %s.",
    "Install and activate additional PHP modules to choose other database types." : "ثبت وفعل مودلات PHP اضافية لاستخدام قاعدة بيانات مختلفة.",
    "For more details check out the documentation." : "للمزيد من التفاصيل، يرجى الإطلاع على الدليل.",
    "Database user" : "مستخدم قاعدة البيانات",
    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
    "Database name" : "اسم قاعدة البيانات",
    "Database tablespace" : "مساحة جدول قاعدة البيانات",
    "Database host" : "خادم قاعدة البيانات",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "يرجى تحديد رقم المنفذ مع اسم المضيف (على سبيل المثال ، mycloud:5432).",
    "Performance warning" : "تحذير حول الأداء",
    "You chose SQLite as database." : "لقد اخترت SQLite كقاعدة بيانات.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "يجب استخدام SQLite فقط في حالات الحد الأدنى من التطوير. للنسخة النهائية، نوصي باستخدام خلفية قاعدة بيانات مختلفة.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "إذا كنت تستخدم عملاء لمزامنة الملفات ، فإن استخدام SQLite لا ينصح به بشدة.",
    "Install" : "تثبيت",
    "Installing …" : "جاري التثبيت ...",
    "Need help?" : "تحتاج إلى مساعدة؟",
    "See the documentation" : "اطلع على التعليمات",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "يبدو أنك تحاول إعادة تثبيت نكست كلاود الخاص بك. ومع ذلك ، فإن الملف CAN_INSTALL مفقود من دليل التثبيت الخاص بك. يرجى إنشاء الملف CAN_INSTALL في مجلد التثبيت الخاص بك للمتابعة.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "تعذر إزالة CAN_INSTALL من مجلد التكوين. الرجاء إزالة هذا الملف يدويا.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "هذا التطبيق يتطلب JavaScript ليتم تشغيله بالطريقة الصحيحة. يرجى {linkstart}تفعيل JavaScript{linkend} وتحديث الصفحة.",
    "Skip to main content" : "تخطّيه وانتقل إلى المحتوى الرئيسي",
    "Skip to navigation of app" : "تجاهل التنقل في التطبيق",
    "Get your own free account" : "احصل على حساب لك بالمجان",
    "Go to %s" : "الإنتقال إلى %s",
    "Confirm your password" : "تأكيد كلمتك السرية",
    "Connect to your account" : "الاتصال بحسابك",
    "Please log in before granting %1$s access to your %2$s account." : "يرجى تسجيل الدخول قبل الحصول على اذن %1$s في حسابك %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "إذا كنت لا تحاول تعيين جهاز أو تطبيق جديد ، فإن شخصًا ما يحاول خداعك لمنحه حق الوصول إلى بياناتك. في هذه الحالة ، لا تقم بالمتابعة وبدلاً من ذلك اتصل بمسؤول النظام.",
    "App token" : "رمز التطبيق",
    "Grant access" : "السماح بالنفاذ",
    "Alternative log in using app token" : "تسجيل الدخول عبر رمز التطبيق",
    "Account access" : "حساب النفاذ",
    "You are about to grant %1$s access to your %2$s account." : "انت على وشك الحصول على اذن %1$s لحسابك %2$s.",
    "Account connected" : "الحساب متصل",
    "Your client should now be connected!" : "من المفترض ان عميلك متصل الان!",
    "You can close this window." : "بإمكانك اغلاق النافذة",
    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
    "Email address" : "عنوان البريد الإلكتروني",
    "Password sent!" : "تم إرسال الكلمة السرية!",
    "You are not authorized to request a password for this share" : "لست مخولاً لطلب كلمة مرور لهذه المشاركة",
    "Two-factor authentication" : "المصادقة بخطوتين",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "تعزيز الآمان مفعل في حسابك. يرجى اختيار وسيلة ثانية للمصادقة:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "تعذر تحميل طريقة واحدة على الأقل من طرق المصادقة الثنائية الممكّنة. الرجاء الاتصال بالمسؤول الخاص بك.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "يتم فرض المصادقة ذات العاملين ولكن لم يتم تكوينها على حسابك. اتصل بالمسؤول للحصول على المساعدة.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "يتم فرض المصادقة ذات العاملين ولكن لم يتم تكوينها على حسابك. الرجاء متابعة إعداد المصادقة الثنائية.",
    "Set up two-factor authentication" : "تعيين المصادقة بخطوتين",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "يتم فرض المصادقة ذات العاملين ولكن لم يتم تكوينها على حسابك. استخدم أحد الرموز الاحتياطية لتسجيل الدخول أو اتصل بالمسؤول للحصول على المساعدة.",
    "Use backup code" : "إستخدم الرمز الإحتياطي",
    "Cancel login" : "إلغاء تسجيل الدخول",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "تعزيز الآمان مفعل في حسابك. تعيين المشغل للخدمة:",
    "Error while validating your second factor" : "خطأ أثناء التحقق من صحة العامل الثاني الخاص بك",
    "Access through untrusted domain" : "الدخول عبر اسم نطاق غير مسجل",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "يرجى التواصل مع مسؤول النظام. بإمكانك إضافة اسم النطاق في اعدادات ملف config/config.php ضمن الخيار \"trusted_domains\".",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "مزيد من المعلومات تجدها في %1$sدليل الاستخدام%2$s.",
    "App update required" : "تحديث التطبيق مطلوب",
    "%1$s will be updated to version %2$s" : "%1$s سيتم التحديث إلى الاصدار %2$s",
    "The following apps will be updated:" : "التطبيقات التالية سوف يتم تحديثها:",
    "These incompatible apps will be disabled:" : "التطبيقات التالية الغير متوافقه سيتم تعطيلها:",
    "The theme %s has been disabled." : "القالب %s معطل. ",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "يرجى سحب نسخة احتياطية من قاعدة البيانات، مجلد الإعدادات config و مجلد data قبل الاستمرار.",
    "Start update" : "تشغيل التحديث",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "لتتجنب انقطاع الاتصال بسبب التثبيت للمساحات الضخمة، بإمكانك استخدام الامر التالي في مجلد التثبيت:",
    "Detailed logs" : "السجلات المفصلة",
    "Update needed" : "التحديث مطلوب",
    "Please use the command line updater because you have a big instance with more than 50 users." : "يرجى استخدام التحديث عبر سطر الاوامر بسبب وجود اكثر من 50 مستخدم.",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "يرجى استخدام خاصية تحديث سطر الاوامر بسبب التحديثات التلقائية ملغية في ملف الاعدادات config.php",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "للمساعدة يُرجى الإطلاع على <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">الدليل</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "أقر عن الخطر المحتمل في حال إكمال عملية التحديث عبر واجهة الرسوم في الويب، لربما يفقد اتصال الجلسة وينتهي الوقت المسموح وفقدان البيانات، ولدي نسخة احتياطية واقر بمعرفتي باستعادة البيانات في حال حدوث خطأ في التحديث.",
    "Upgrade via web on my own risk" : "تحديث عبر واجهة الويب على مسؤليتي الشخصية",
    "Maintenance mode" : "وضع الصيانة",
    "This %s instance is currently in maintenance mode, which may take a while." : "هذا %s في وضع الصيانة، قد يستغرق ذلك بعض الوقت.",
    "This page will refresh itself when the instance is available again." : "سوف يتم تحديث الصفحة في حين الخادم جاهز للاستخدام مجددا.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "تواصل مع مسؤول النظام اذا استمرت هذه الرسالة بالظهور دائما أو بشكل مفاجئ.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "إصدار المجتمع هذا من Nextcloud غير مدعوم والإشعارات الفورية غير متاحة.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: تحديث الجدول %s",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "لا يحتوي رأس HTTP \"{header}\" على \"{expected}\". يعد هذا خطرًا محتملاً على الأمان أو الخصوصية ، حيث يوصى بضبط هذا الإعداد وفقًا لذلك.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "تم إرسال رسالة إعادة تعيين كلمة المرور إلى عنوان البريد الإلكتروني لهذا الحساب. إذا لم تستلمها ، فتحقق من مجلدات البريد الغير هام / غير المرغوب فيه أو اطلب المساعدة من المسؤول المحلي.",
    "If it is not there ask your local administrator." : "إذا لم يكن هناك اسأل المسؤول التقني المحلي.",
    "Collaboratively edit office documents." : "تحرير مستندات المكتب بشكل تعاوني.",
    "Local document editing back-end used by the Collabora Online app." : "خلفية تحرير المستندات المحلية المستخدمة بواسطة تطبيق Collabora Online.",
    "restricted" : "مُقيَّد",
    "invisible" : "مخفي",
    "File not found" : "لم يتم العثور على الملف",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "لا يمكن العثور على المستند، ربما المشاركة محذوفه او منتهيه؟",
    "More" : "المزيد",
    "More apps menu" : "المزيد من قائمة التطبيقات",
    "Contacts" : "جهات الإتصال",
    "Contacts menu" : "قائمة جهات الإتصال",
    "Setup two-factor authentication" : "تعيين المصادقة بخطوتين",
    "Press enter to start searching" : "اضغط على Enter لبدء البحث"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
